==> mysql-8.0_8.0.19.orig.tar.gz: mysql-8.0.19/plugin/x/src/delete_statement_builder.cc <==
/*
 * Copyright (c) 2015, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms,
 * as designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have included with MySQL.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */

#include "plugin/x/src/delete_statement_builder.h"

#include "plugin/x/ngs/include/ngs/protocol/protocol_protobuf.h"

namespace xpl {

void Delete_statement_builder::build(const Delete &msg) const {
  m_builder.put("DELETE FROM ");
  add_collection(msg.collection());
  add_filter(msg.criteria());
  add_order(msg.order());
  add_limit(msg, true);
}

}  // namespace xpl

==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/plugin/x/src/delete_statement_builder.cc <==
/*
 * Copyright (c) 2015, 2021, Oracle and/or its affiliates.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms,
 * as designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have included with MySQL.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */

#include "plugin/x/src/delete_statement_builder.h"

#include "plugin/x/src/ngs/protocol/protocol_protobuf.h"

namespace xpl {

void Delete_statement_builder::build(const Delete &msg) const {
  m_builder.put("DELETE FROM ");
  add_collection(msg.collection());
  add_filter(msg.criteria());
  add_order(msg.order());
  add_limit(msg, true);
}

}  // namespace xpl
